==> peaceful-progression-1.1.0-sources.jar: xen42/peacefulitems/entity/EndClamEntityModel.java <==
package xen42.peacefulitems.entity;

import net.minecraft.class_5597;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_630;
import net.minecraft.class_7094;
import net.minecraft.class_7184;
import org.joml.Vector3f;
import xen42.peacefulitems.entities.EndClamEntity;

public class EndClamEntityModel extends class_5597<EndClamEntity> {
	public final class_630 clam;
	public final class_630 bottom_shell;
	public final class_630 top_shell;

	protected EndClamEntityModel(class_630 root) {
        super();
		this.clam = root.method_32086("clam");
		this.bottom_shell = this.clam.method_32086("bottom_shell");
		this.top_shell = this.clam.method_32086("top_shell");
	}

	@Override
	public class_630 method_32008() {
		return this.clam;
	}
    
	@SuppressWarnings("unused")
	public static class_5607 getTexturedModelData() {
		class_5609 modelData = new class_5609();
		class_5610 modelPartData = modelData.method_32111();

		class_5610 clam = modelPartData.method_32117("clam", class_5606.method_32108(), class_5603.method_32090(0.0F, 24.0F, 0.0F));

		class_5610 bottom_shell = clam.method_32117("bottom_shell", class_5606.method_32108().method_32101(0, 0).method_32098(-4.0F, 0.0F, -9.0F, 8.0F, 1.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32090(0.0F, -3.0F, 5.0F));

		class_5610 top_r1 = bottom_shell.method_32117("top_r1", class_5606.method_32108().method_32101(0, 28).method_32096().method_32098(-3.0F, -1.0F, -3.0F, 6.0F, 1.0F, 6.0F, new class_5605(0.0F)).method_32106(false), class_5603.method_32091(0.0F, 2.0F, -5.0F, 3.1416F, 0.0F, 0.0F));

		class_5610 back_r1 = bottom_shell.method_32117("back_r1", class_5606.method_32108().method_32101(0, 11).method_32098(-2.0F, -0.5F, -0.5F, 4.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.5F, -0.5F, 0.0F, 0.0F, -3.1416F));

		class_5610 outer_r1 = bottom_shell.method_32117("outer_r1", class_5606.method_32108().method_32101(0, 17).method_32096().method_32098(-4.0F, -0.5F, -4.0F, 8.0F, 1.0F, 8.0F, new class_5605(0.0F)).method_32106(false), class_5603.method_32091(0.0F, 1.5F, -5.0F, 0.0F, 0.0F, 3.1416F));

		class_5610 top_shell = clam.method_32117("top_shell", class_5606.method_32108().method_32101(0, 17).method_32098(-4.0F, -2.0F, -9.0F, 8.0F, 1.0F, 8.0F, new class_5605(0.0F))
		.method_32101(0, 11).method_32098(-2.0F, -1.0F, -1.0F, 4.0F, 1.0F, 1.0F, new class_5605(0.0F))
		.method_32101(0, 28).method_32098(-3.0F, -3.0F, -8.0F, 6.0F, 1.0F, 6.0F, new class_5605(0.0F)), class_5603.method_32090(0.0F, -3.0F, 5.0F));

		class_5610 inner_r1 = top_shell.method_32117("inner_r1", class_5606.method_32108().method_32101(0, 0).method_32098(-4.0F, -0.5F, -4.0F, 8.0F, 1.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -0.5F, -5.0F, 3.1416F, 0.0F, 0.0F));
		return class_5607.method_32110(modelData, 64, 64);
	}

	@Override
	public void setAngles(EndClamEntity endClamEntityRenderState, float limbAngle, float limbDistance, float animationProgress, float headYaw, float headPitch) {
		this.method_32008().method_32088().forEach(class_630::method_41923);

		this.animate(endClamEntityRenderState.idleAnimationState, EndClamAnimation.IDLE, endClamEntityRenderState.field_6012, 1.0F);
		this.animate(endClamEntityRenderState.hitAnimationState, EndClamAnimation.HIT, endClamEntityRenderState.field_6012, 1.0F);
		this.animate(endClamEntityRenderState.yawnAnimationState, EndClamAnimation.YAWN, endClamEntityRenderState.field_6012, 1.0F);
		this.animate(endClamEntityRenderState.openAnimationState, EndClamAnimation.OPEN, endClamEntityRenderState.field_6012, 1.0F);
	}

	private void animate(class_7094 animationState, class_7184 animation, float animationProgress, float speedMultiplier) {
		this.method_43782(animationState, animation, animationProgress, speedMultiplier);
	}
}

==> peaceful-progression-1.1.1-sources.jar: xen42/peacefulitems/entity/EndClamEntityModel.java <==
package xen42.peacefulitems.entity;

import net.minecraft.class_11509;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_583;
import net.minecraft.class_630;

public class EndClamEntityModel extends class_583<EndClamEntityRenderState> {
	public final class_630 clam;
	public final class_630 bottom_shell;
	public final class_630 top_shell;
    private final class_11509 yawn;
    private final class_11509 open;
    private final class_11509 idle;
    private final class_11509 hit;

    protected EndClamEntityModel(class_630 root) {
        super(root);
		this.clam = root.method_32086("clam");
		this.bottom_shell = this.clam.method_32086("bottom_shell");
		this.top_shell = this.clam.method_32086("top_shell");
        this.yawn = EndClamAnimation.YAWN.method_71979(root);
        this.open = EndClamAnimation.OPEN.method_71979(root);
        this.idle = EndClamAnimation.IDLE.method_71979(root);
        this.hit = EndClamAnimation.HIT.method_71979(root);
	}
    
	@SuppressWarnings("unused")
	public static class_5607 getTexturedModelData() {
		class_5609 modelData = new class_5609();
		class_5610 modelPartData = modelData.method_32111();

		class_5610 clam = modelPartData.method_32117("clam", class_5606.method_32108(), class_5603.method_32090(0.0F, 24.0F, 0.0F));

		class_5610 bottom_shell = clam.method_32117("bottom_shell", class_5606.method_32108().method_32101(0, 0).method_32098(-4.0F, 0.0F, -9.0F, 8.0F, 1.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32090(0.0F, -3.0F, 5.0F));

		class_5610 top_r1 = bottom_shell.method_32117("top_r1", class_5606.method_32108().method_32101(0, 28).method_32096().method_32098(-3.0F, -1.0F, -3.0F, 6.0F, 1.0F, 6.0F, new class_5605(0.0F)).method_32106(false), class_5603.method_32091(0.0F, 2.0F, -5.0F, 3.1416F, 0.0F, 0.0F));

		class_5610 back_r1 = bottom_shell.method_32117("back_r1", class_5606.method_32108().method_32101(0, 11).method_32098(-2.0F, -0.5F, -0.5F, 4.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.5F, -0.5F, 0.0F, 0.0F, -3.1416F));

		class_5610 outer_r1 = bottom_shell.method_32117("outer_r1", class_5606.method_32108().method_32101(0, 17).method_32096().method_32098(-4.0F, -0.5F, -4.0F, 8.0F, 1.0F, 8.0F, new class_5605(0.0F)).method_32106(false), class_5603.method_32091(0.0F, 1.5F, -5.0F, 0.0F, 0.0F, 3.1416F));

		class_5610 top_shell = clam.method_32117("top_shell", class_5606.method_32108().method_32101(0, 17).method_32098(-4.0F, -2.0F, -9.0F, 8.0F, 1.0F, 8.0F, new class_5605(0.0F))
		.method_32101(0, 11).method_32098(-2.0F, -1.0F, -1.0F, 4.0F, 1.0F, 1.0F, new class_5605(0.0F))
		.method_32101(0, 28).method_32098(-3.0F, -3.0F, -8.0F, 6.0F, 1.0F, 6.0F, new class_5605(0.0F)), class_5603.method_32090(0.0F, -3.0F, 5.0F));

		class_5610 inner_r1 = top_shell.method_32117("inner_r1", class_5606.method_32108().method_32101(0, 0).method_32098(-4.0F, -0.5F, -4.0F, 8.0F, 1.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -0.5F, -5.0F, 3.1416F, 0.0F, 0.0F));
		return class_5607.method_32110(modelData, 64, 64);
	}

	@Override
	public void setAngles(EndClamEntityRenderState endClamEntityRenderState) {
		super.method_2819(endClamEntityRenderState);

		this.idle.method_71986(endClamEntityRenderState.idleAnimationState, endClamEntityRenderState.field_53328, 1.0F);
		this.hit.method_71986(endClamEntityRenderState.hitAnimationState, endClamEntityRenderState.field_53328, 1.0F);
		this.yawn.method_71986(endClamEntityRenderState.yawnAnimationState, endClamEntityRenderState.field_53328, 1.0F);
		this.open.method_71986(endClamEntityRenderState.openAnimationState, endClamEntityRenderState.field_53328, 1.0F);
	}
}
